<?php
/**
 * Single variation cart form
 */

defined( 'ABSPATH' ) || exit;

global $product;

// Enqueue variation scripts.
wp_enqueue_script( 'wc-add-to-cart-variation' );

// Get Available variations?
$get_variations = count( $product->get_children() ) <= apply_filters( 'woocommerce_ajax_variation_threshold', 30, $product );

$available_variations = $get_variations ? $product->get_available_variations() : false;
$attributes           = $product->get_variation_attributes();
$selected_attributes  = $product->get_default_attributes();

$attribute_keys  = array_keys( $attributes );
$variations_json = wp_json_encode( $available_variations );
$variations_attr = function_exists( 'wc_esc_json' ) ? wc_esc_json( $variations_json ) : _wp_specialchars( $variations_json, ENT_QUOTES, 'UTF-8', true );

?>

<form class="variations_form cart" action="<?php echo esc_url( apply_filters( 'woocommerce_add_to_cart_form_action', $product->get_permalink() ) ); ?>" method="post" enctype='multipart/form-data' data-product_id="<?php echo absint( $product->get_id() ); ?>" data-product_variations="<?php echo esc_attr($variations_attr); // WPCS: XSS ok. ?>">
		 <?php wp_nonce_field( 'qof_security_nonce_action', 'qof_security_fields_nonce' ); ?>
	<?php do_action( 'woocommerce_before_variations_form' ); ?>

	<?php if ( empty( $available_variations ) && false !== $available_variations ) : ?>
		<p class="stock out-of-stock"><?php echo esc_html( apply_filters( 'woocommerce_out_of_stock_message', __( 'This product is currently out of stock and unavailable.', 'woocommerce' ) ) ); ?></p>
	<?php else : ?>
		<table class="variations" cellspacing="0">
			<tbody>
				<?php foreach ( $attributes as $attribute_name => $options ) : ?>
					<tr>
						<td class="label"><label for="<?php echo esc_attr( sanitize_title( $attribute_name ) ); ?>"><?php echo esc_attr(wc_attribute_label( $attribute_name )); // WPCS: XSS ok. ?></label></td>
						<td class="value">
							<?php
								wc_dropdown_variation_attribute_options(
									array(
										'options'   => $options,
										'attribute' => $attribute_name,
										'product'   => $product,
									)
								);
								echo end( $attribute_keys ) === $attribute_name ? wp_kses_post( apply_filters( 'woocommerce_reset_variations_link', '<a class="reset_variations" href="#">' . esc_html__( 'Clear', 'woocommerce' ) . '</a>' ) ) : '';
							?>
						</td>
					</tr>
				<?php endforeach; ?>
			</tbody>
		</table>

		<div class="single_variation_wrap">

			<div class="woocommerce-variation-add-to-cart variations_button">

				<?php 
				if ( isset( $_POST['qof_security_nonce_action'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['qof_security_nonce_action'], 'qof_security_fields_nonce' ) ) ) ) {
			print 'Sorry, your nonce did not verify.';
			exit;
				}

				woocommerce_quantity_input(
					array(
						'min_value'   => apply_filters( 'woocommerce_quantity_input_min', $product->get_min_purchase_quantity(), $product ),
						'max_value'   => apply_filters( 'woocommerce_quantity_input_max', $product->get_max_purchase_quantity(), $product ),


						'input_value' => isset( $_POST['quantity'] ) ? wc_stock_amount(sanitize_text_field( wp_unslash( $_POST['quantity'] ) )) : $product->get_min_purchase_quantity(), // WPCS: CSRF ok, input var ok.
					)
				);


				if ( 'yes' === $qof_show_single_cart ) : 
					?>
					<button type="button" class="single_add_to_cart_button qof_add_to_cart button alt" disabled wc-variation-selection-needed data-product_id ="<?php echo absint( $product->get_id() ); ?>]"><?php echo esc_html( $product->single_add_to_cart_text() ); ?></button>
				<?php endif; ?>
				<label class="lab_out_message" style="display: none;">Product out of Stock.</label>
				<input type="hidden" class="bulk_quantity" name="bulk_quantity[<?php echo absint( $product->get_id() ); ?>]" value="1" />
				<input type="hidden" name="add-to-cart" value="<?php echo absint( $product->get_id() ); ?>" />
				<input type="hidden" name="product_id" value="<?php echo absint( $product->get_id() ); ?>" />
				<input type="hidden" name="variation_id" class="variation_id" value="0" />
				<div class="selected_attributes">
				</div>
			</div> 
		</div>
	<?php endif; ?>

</form>
